==> thx_store-0.0.2-py3-none-any.whl: thx/store/admin.py <==
# -*- coding: utf-8 -*-
from django.contrib import admin
from django.utils.translation import ugettext_lazy as _

from jmb.filters.admin import AdvancedSearchModelAdmin
from thx.core.admin import UserAdminMixin
from . import models


class StoreAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('code', 'name',)
    advanced_search_fields = (
        ('status', 'name__icontains',),
    )
    list_filter = ('status', 'default',)
    fieldsets = (
        (_('general information'), {
           'fields': ('code', 'name', 'description', 'default')
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('pk', 'status', 'code', 'name', 'default', 'ordering')
    list_display_links = ('name',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')


class StoreAddressAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ()
    advanced_search_fields = ()
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
            'fields': (
                'address_scopes', 'address_type', 'name', 'number', 'crossed', 'scale',
                'floor', 'zip_code', 'locality', 'province', 'country', 'post_office',
            )
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = (
        'pk', 'status',
        'address_type', 'name', 'number', 'crossed', 'scale', 'floor',
        'zip_code', 'locality', 'province', 'country', 'post_office',
        'ordering'
    )
    list_display_links = ()
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')


class StoreCauseAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('name',)
    advanced_search_fields = ()
    fieldsets = (
        (_('general information'), {
           'fields': (
               'code', 'name', 'store', 'category', 'description', 'store_document',
               'move', 'stock', 'busy', 'ddt_required', 'invoice_required', 'default',
               'default_for_shop', 'model_template',
           )
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = (
        'pk', 'status', 'code', 'name', 'store', 'store_document',
        'move', 'stock', 'busy', 'ddt_required', 'invoice_required', 'default',
        'ordering'
    )
    list_display_links = ('name',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')


class StoreDocumentAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('name',)
    advanced_search_fields = ()
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
           'fields': ('code', 'name', 'description',)
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('pk', 'status', 'code', 'name', 'description', 'ordering')
    list_display_links = ('name',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')


class StoreDocumentNumberAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ()
    advanced_search_fields = ()
    list_filter = ()
    fieldsets = (
        (_('general information'), {
           'fields': ('store_document', 'application', 'year', 'last_number', 'last_date',)
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering',)
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = (
        'pk', 'store_document', 'application', 'year', 'last_number', 'last_date', 'ordering'
    )
    list_display_links = ('application',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')


admin.site.register(models.Store, StoreAdmin)
admin.site.register(models.StoreAddress, StoreAddressAdmin)
admin.site.register(models.StoreCause, StoreCauseAdmin)
admin.site.register(models.StoreDocument, StoreDocumentAdmin)
admin.site.register(models.StoreDocumentNumber, StoreDocumentNumberAdmin)

==> thx_store-0.1.0-py3-none-any.whl: thx/store/admin.py <==
# -*- coding: utf-8 -*-
from django.contrib import admin
from django.utils.translation import gettext_lazy as _

from jmb.filters.admin import AdvancedSearchModelAdmin
from thx.core.admin import UserAdminMixin
from . import models


class StoreAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('code', 'name',)
    advanced_search_fields = (
        ('status', 'name__icontains',),
    )
    list_filter = ('status', 'default',)
    fieldsets = (
        (_('general information'), {
           'fields': ('code', 'name', 'description', 'default')
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('id', 'status', 'code', 'name', 'default', 'ordering')
    list_display_links = ('name',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')


class StoreAddressAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ()
    advanced_search_fields = (
        ('store__name__icontains',),
        ('name__icontains:address name', 'number:address number'),
        ('zip_code',),
        ('locality__icontains', 'province__icontains'),
        ('country__name__icontains', 'post_office__icontains'),
    )
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
            'fields': (
                'store', 'address_scopes', 'address_type', 'name', 'number', 'crossed', 'scale',
                'floor', 'zip_code', 'locality', 'province', 'country', 'post_office',
            )
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = (
        'id', 'status', 'store',
        'address_type', 'name', 'number', 'crossed', 'scale', 'floor',
        'zip_code', 'locality', 'province', 'country', 'post_office',
        'ordering'
    )
    list_display_links = ('store',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    autocomplete_fields = ('store', 'country', 'address_scopes')


class StoreCauseAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('name',)
    advanced_search_fields = (
        ('code', 'store__name__icontains'),
        ('description__icontains',),
    )
    fieldsets = (
        (_('general information'), {
           'fields': (
               'code', 'name', 'store', 'category', 'description', 'store_document',
               'move', 'stock', 'busy', 'ddt_required', 'invoice_required', 'default',
               'default_for_shop', 'model_template',
           )
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = (
        'id', 'status', 'code', 'name', 'store', 'store_document',
        'move', 'stock', 'busy', 'ddt_required', 'invoice_required', 'default',
        'ordering'
    )
    list_display_links = ('name',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    autocomplete_fields = ('store',)


class StoreDocumentAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('name',)
    advanced_search_fields = (
        ('code__iexact', 'name__icontains', 'description__icontains'),
    )
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
           'fields': ('code', 'name', 'description',)
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('id', 'status', 'code', 'name', 'description', 'ordering')
    list_display_links = ('name',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')


class StoreDocumentNumberAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ()
    advanced_search_fields = ()
    list_filter = ()
    fieldsets = (
        (_('general information'), {
           'fields': ('store_document', 'application', 'year', 'last_number', 'last_date',)
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering',)
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = (
        'id', 'store_document', 'application', 'year', 'last_number', 'last_date', 'ordering'
    )
    list_display_links = ('application',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    autocomplete_fields = ('store_document',)


admin.site.register(models.Store, StoreAdmin)
admin.site.register(models.StoreAddress, StoreAddressAdmin)
admin.site.register(models.StoreCause, StoreCauseAdmin)
admin.site.register(models.StoreDocument, StoreDocumentAdmin)
admin.site.register(models.StoreDocumentNumber, StoreDocumentNumberAdmin)
